# Table of Contents

- [application-rationalization-evaluate-data](<./application-rationalization-evaluate-data.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
  - [Table of Contents](<./SAP-LeanIX/Table-of-Contents.md>)
- [Step 4: Evaluate Data](<./Step-4-Evaluate-Data.md>)
  - [Before You Start](<./Step-4-Evaluate-Data/Before-You-Start.md>)
  - [Evaluate by Gartner TIME Framework](<./Step-4-Evaluate-Data/Evaluate-by-Gartner-TIME-Framework.md>)
  - [Prioritize with Reports](<./Step-4-Evaluate-Data/Prioritize-with-Reports.md>)
  - [Record Rationalization Decisions](<./Step-4-Evaluate-Data/Record-Rationalization-Decisions.md>)
  - [Related Resources](<./Step-4-Evaluate-Data/Related-Resources.md>)
  - [Was this page helpful?](<./Step-4-Evaluate-Data/Was-this-page-helpful.md>)
